@@ -734,11 +734,7 @@ G80LoadPalette(ScrnInfoPtr pScrn, int numColors, int *indices, LOCO *colors,
         }
 
         /* Make the change through RandR */
-#ifdef RANDR_12_INTERFACE
         RRCrtcGammaSet(crtc->randr_crtc, lut_r, lut_g, lut_b);
-#else
-        crtc->funcs->gamma_set(crtc, lut_r, lut_g, lut_b, 256);
-#endif
     }
 }
 
